@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: StatisticsHandler.py 13129 2021-07-30 05:11:59Z Casey $
+# $Id: StatisticsHandler.py 13182 2021-08-04 07:20:14Z Casey $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Casey $
-# $Date: 2021-07-30 13:11:59 +0800 (Fri, 30 Jul 2021) $
-# $Revision: 13129 $
+# $Date: 2021-08-04 15:20:14 +0800 (Wed, 04 Aug 2021) $
+# $Revision: 13182 $
 
 from datetime import timedelta, datetime
 
@@ -36,7 +36,7 @@ STATUS_DICT = dict(ContactMailingStatus.STATUS_CHOICES)
 STATUS_NAMES = STATUS_DICT.values()
 STATUS_CODE = STATUS_DICT.keys()
 
-_STAUS_VALUES = [
+_STATUS_NAMES = [
     STATUS_DICT[ContactMailingStatus.SENT],
     STATUS_DICT[ContactMailingStatus.ERROR],
     STATUS_DICT[ContactMailingStatus.INVALID],
@@ -83,13 +83,6 @@ if settings.DATABASE_ENGINE == 'mysql':
                     return date_format(d, format) ;
                 """
         )
-
-def getStatusName():
-    _STATUS_NAMES = []
-    for i in _STAUS_VALUES:
-        _STATUS_NAMES.append(str(i))
-
-    return _STATUS_NAMES
     
 def getDateRange(startDate, endDate):
     """
@@ -789,9 +782,6 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
     yaxisMaxValue = max(tmp)
     del tmp
 
-
-    _STATUS_NAMES = getStatusName()
-
     response = {
         'context': {
             'email': context,
@@ -866,8 +856,6 @@ def getStatisticsTotalRateData(reqestGetData, subscriberCount,
 
         rates.append((d, value))
 
-    _STATUS_NAMES = getStatusName()
-
     response = {
         'context': dict(rates),
         'contextCount': data,
